@@ -1,4 +1,3 @@
-from django.conf import settings
 from django.core.urlresolvers import reverse
 from django.http import HttpResponse
 from django.utils import feedgenerator
@@ -6,8 +5,6 @@ from django.utils.translation import ugettext_lazy as _
 
 from sentry.models import Message, GroupedMessage
 
-import logging
-
 class MessageFeed(object):
     def __call__(self, request):
         feed_dict = {
